@@ -1,5 +1,6 @@
 from django import template
 from django.forms.widgets import Media
+from django.template.base import Context
 from django.utils.safestring import mark_safe
 
 from secrets import token_hex
@@ -15,14 +16,15 @@ def media_tag(media_type):  # type: Literal["css", "js"] -> Callable
     return media
 
 
-def ensure_context_media(context):
-    if not CONTEXT_KEY in context:
-        context[CONTEXT_KEY] = {"media": Media()}
+def ensure_context_media(root_context: dict):
+    if not CONTEXT_KEY in root_context:
+        root_context[CONTEXT_KEY] = {"media": Media()}
 
 
-def add_media(context, media):
-    ensure_context_media(context)
-    context[CONTEXT_KEY]["media"] += media
+def add_media(context: Context, media):
+    root_context = context.dicts[0]
+    ensure_context_media(root_context)
+    root_context[CONTEXT_KEY]["media"] += media
 
 
 class MediaNode(template.Node):
